@@ -78,7 +78,7 @@ impl fmt::Display for Protocol<'_> {
 
 impl fmt::Debug for Protocol<'_> {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(f, "{}", self)
+        write!(f, "{self}")
     }
 }
 
@@ -113,7 +113,7 @@ impl fmt::Display for ProtocolMut<'_> {
 
 impl fmt::Debug for ProtocolMut<'_> {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(f, "{}", self)
+        write!(f, "{self}")
     }
 }
 
@@ -142,7 +142,7 @@ impl fmt::Display for Address<'_> {
 
 impl fmt::Debug for Address<'_> {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(f, "{}", self)
+        write!(f, "{self}")
     }
 }
 
@@ -183,7 +183,7 @@ impl fmt::Display for AddressMut<'_> {
 
 impl fmt::Debug for AddressMut<'_> {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(f, "{}", self)
+        write!(f, "{self}")
     }
 }
 
@@ -231,7 +231,7 @@ impl fmt::Display for Metadata<'_> {
 
 impl fmt::Debug for Metadata<'_> {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(f, "{}", self)
+        write!(f, "{self}")
     }
 }
 
@@ -316,7 +316,7 @@ impl fmt::Display for MetadataMut<'_> {
 
 impl fmt::Debug for MetadataMut<'_> {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(f, "{}", self)
+        write!(f, "{self}")
     }
 }
 
@@ -361,7 +361,7 @@ impl fmt::Display for Config<'_> {
 
 impl fmt::Debug for Config<'_> {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(f, "{}", self)
+        write!(f, "{self}")
     }
 }
 
@@ -446,7 +446,7 @@ impl fmt::Display for ConfigMut<'_> {
 
 impl fmt::Debug for ConfigMut<'_> {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(f, "{}", self)
+        write!(f, "{self}")
     }
 }
 
@@ -517,7 +517,7 @@ impl EndPoint {
         self.inner.as_str()
     }
 
-    pub fn split(&self) -> (Protocol, Address, Metadata, Config) {
+    pub fn split(&self) -> (Protocol<'_>, Address<'_>, Metadata<'_>, Config<'_>) {
         (
             self.protocol(),
             self.address(),
@@ -526,35 +526,35 @@ impl EndPoint {
         )
     }
 
-    pub fn protocol(&self) -> Protocol {
+    pub fn protocol(&self) -> Protocol<'_> {
         Protocol(protocol(self.inner.as_str()))
     }
 
-    pub fn protocol_mut(&mut self) -> ProtocolMut {
+    pub fn protocol_mut(&mut self) -> ProtocolMut<'_> {
         ProtocolMut(self)
     }
 
-    pub fn address(&self) -> Address {
+    pub fn address(&self) -> Address<'_> {
         Address(address(self.inner.as_str()))
     }
 
-    pub fn address_mut(&mut self) -> AddressMut {
+    pub fn address_mut(&mut self) -> AddressMut<'_> {
         AddressMut(self)
     }
 
-    pub fn metadata(&self) -> Metadata {
+    pub fn metadata(&self) -> Metadata<'_> {
         Metadata(metadata(self.inner.as_str()))
     }
 
-    pub fn metadata_mut(&mut self) -> MetadataMut {
+    pub fn metadata_mut(&mut self) -> MetadataMut<'_> {
         MetadataMut(self)
     }
 
-    pub fn config(&self) -> Config {
+    pub fn config(&self) -> Config<'_> {
         Config(config(self.inner.as_str()))
     }
 
-    pub fn config_mut(&mut self) -> ConfigMut {
+    pub fn config_mut(&mut self) -> ConfigMut<'_> {
         ConfigMut(self)
     }
 
@@ -577,7 +577,7 @@ impl fmt::Display for EndPoint {
 
 impl fmt::Debug for EndPoint {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(f, "{}", self)
+        write!(f, "{self}")
     }
 }
 
